Command

Enum Command 

pub enum Command {
Show 26 variants Amend { move_options: MoveOptions, untracked_file_strategy: Option<UntrackedFileStrategy>, }, BugReport, Difftool(Opts), Gc, Hide { revsets: Vec<Revset>, resolve_revset_options: ResolveRevsetOptions, no_delete_branches: bool, recursive: bool, }, Hook(HookArgs), Init(InitArgs), InstallManPages(InstallManPagesArgs), Move { source: Vec<Revset>, base: Vec<Revset>, exact: Vec<Revset>, dest: Option<Revset>, resolve_revset_options: ResolveRevsetOptions, move_options: MoveOptions, fixup: bool, insert: bool, dry_run: bool, }, Next { traverse_commits_options: TraverseCommitsOptions, }, Prev { traverse_commits_options: TraverseCommitsOptions, }, Query(QueryArgs), Repair { dry_run: bool, }, Restack { revsets: Vec<Revset>, resolve_revset_options: ResolveRevsetOptions, move_options: MoveOptions, }, Record(RecordArgs), Reword { revsets: Vec<Revset>, resolve_revset_options: ResolveRevsetOptions, force_rewrite_public_commits: bool, message_args: MessageArgs, discard: bool, }, Smartlog(SmartlogArgs), Snapshot { subcommand: SnapshotSubcommand, }, Split { revset: Revset, files: Vec<String>, before: bool, detach: bool, discard: bool, resolve_revset_options: ResolveRevsetOptions, move_options: MoveOptions, }, Submit(SubmitArgs), Switch { switch_options: SwitchOptions, }, Sync { pull: bool, move_options: MoveOptions, revsets: Vec<Revset>, resolve_revset_options: ResolveRevsetOptions, }, Test(TestArgs), Undo { interactive: bool, yes: bool, }, Unhide { revsets: Vec<Revset>, resolve_revset_options: ResolveRevsetOptions, recursive: bool, }, Wrap { git_executable: Option<PathBuf>, command: WrappedCommand, },
}
FIXME: write man-page text

Variants



Amend

Amend the current HEAD commit.

Fields

move_options: MoveOptions

Options for moving commits.

untracked_file_strategy: Option<UntrackedFileStrategy>

How should newly encountered, untracked files be handled?



BugReport

Gather information about recent operations to upload as part of a bug report.



Difftool(Opts)

Use the partial commit selector UI as a Git-compatible difftool; see git-difftool(1) for more information on Git difftools.



Gc

Run internal garbage collection.



Hide

Hide the provided commits from the smartlog.

Fields

revsets: Vec<Revset>

Zero or more commits to hide.

resolve_revset_options: ResolveRevsetOptions

Options for resolving revset expressions.

no_delete_branches: bool

Don’t delete branches that point to commits that would be hidden. (Those commits will remain visible as a result.)

recursive: bool

Also recursively hide all visible children commits of the provided commits.



Hook(HookArgs)

Internal use.



Init(InitArgs)

Initialize the branchless workflow for this repository.



InstallManPages(InstallManPagesArgs)

Install git-branchless’s man-pages to the given path.



Move

Move a subtree of commits from one location to another.

By default, git move tries to move the entire current stack if you don’t pass a --source or --base option (equivalent to writing --base HEAD).

By default, git move attempts to rebase all commits in-memory. If you want to force an on-disk rebase, pass the --on-disk flag. Note that post-commit hooks are not called during in-memory rebases.

Fields

source: Vec<Revset>

The source commit to move. This commit, and all of its descendants, will be moved.

base: Vec<Revset>

A commit inside a subtree to move. The entire subtree, starting from the main branch, will be moved, not just the commits descending from this commit.

exact: Vec<Revset>

A set of specific commits to move. These will be removed from their current locations and any unmoved children will be moved to their nearest unmoved ancestor.

dest: Option<Revset>

The destination commit to move all source commits onto. If not provided, defaults to the current commit.

resolve_revset_options: ResolveRevsetOptions

Options for resolving revset expressions.

move_options: MoveOptions

Options for moving commits.

fixup: bool

Combine the moved commits and squash them into the destination commit.

insert: bool

Insert the subtree between the destination and it’s children, if any. Only supported if the moved subtree has a single head.

dry_run: bool

Test whether an in-memory rebase would succeed.



Next

Move to a later commit in the current stack.

Fields

traverse_commits_options: TraverseCommitsOptions

Options for traversing commits.



Prev

Move to an earlier commit in the current stack.

Fields

traverse_commits_options: TraverseCommitsOptions

Options for traversing commits.



Query(QueryArgs)

Query the commit graph using the “revset” language and print matching commits.

See https://github.com/arxanas/git-branchless/wiki/Reference:-Revsets to learn more about revsets.

The outputted commits are guaranteed to be topologically sorted, with ancestor commits appearing first.



Repair

Restore internal invariants by reconciling the internal operation log with the state of the Git repository.

Fields

dry_run: bool

Apply changes.



Restack

Fix up commits abandoned by a previous rewrite operation.

Fields

revsets: Vec<Revset>

The IDs of the abandoned commits whose descendants should be restacked. If not provided, all abandoned commits are restacked.

resolve_revset_options: ResolveRevsetOptions

Options for resolving revset expressions.

move_options: MoveOptions

Options for moving commits.



Record(RecordArgs)

Create a commit by interactively selecting which changes to include.



Reword

Reword commits.

Fields

revsets: Vec<Revset>

Zero or more commits to reword.

resolve_revset_options: ResolveRevsetOptions

Options for resolving revset expressions.

force_rewrite_public_commits: bool

Force rewording public commits, even though other people may have access to those commits.

message_args: MessageArgs

Options for supplying commit messages.

discard: bool

Throw away the original commit messages.

If commit.template is set, then the editor is pre-populated with that; otherwise, the editor starts empty.



Smartlog(SmartlogArgs)

smartlog command.



Snapshot

Manage working copy snapshots.

Fields

subcommand: SnapshotSubcommand

The subcommand to run.



Split

Split commits.

Fields

revset: Revset

Commit to split. If a revset is given, it must resolve to a single commit.

files: Vec<String>

Files to extract from the commit.

before: bool

Insert the extracted commit before (as a parent of) the split commit.

detach: bool

Restack any descendents onto the split commit, not the extracted commit.

discard: bool

After extracting the changes, don’t recommit them.

resolve_revset_options: ResolveRevsetOptions

Options for resolving revset expressions.

move_options: MoveOptions

Options for moving commits.



Submit(SubmitArgs)

Push commits to a remote.



Switch

Switch to the provided branch or commit.

Fields

switch_options: SwitchOptions

Options for switching.



Sync

Move any local commit stacks on top of the main branch.

Fields

pull: bool

Run git fetch to update remote references before carrying out the sync.

move_options: MoveOptions

Options for moving commits.

revsets: Vec<Revset>

The commits whose stacks will be moved on top of the main branch. If no commits are provided, all draft commits will be synced.

resolve_revset_options: ResolveRevsetOptions

Options for resolving revset expressions.



Test(TestArgs)

Run a command on each commit in a given set and aggregate the results.



Undo

Browse or return to a previous state of the repository.

Fields

interactive: bool

Interactively browse through previous states of the repository before selecting one to return to.

yes: bool

Skip confirmation and apply changes immediately.



Unhide

Unhide previously-hidden commits from the smartlog.

Fields

revsets: Vec<Revset>

Zero or more commits to unhide.

resolve_revset_options: ResolveRevsetOptions

Options for resolving revset expressions.

recursive: bool

Also recursively unhide all children commits of the provided commits.



Wrap

Wrap a Git command inside a branchless transaction.

Fields

git_executable: Option<PathBuf>

The git executable to invoke.

command: WrappedCommand

The arguments to pass to git.