pub struct MessageArgs {
pub messages: Vec<String>,
pub commit_to_fixup: Option<Revset>,
}Expand description
Specify commit messages
Fields
messages: Vec<String>The commit message to use. Multiple messages will be combined
as separate paragraphs, similar to git commit.
If not provided, you will be prompted to provide a commit message
interactively.
commit_to_fixup: Option<Revset>A commit to “fix up”. The message will be prefixed with fixup!
following the supplied commit, suitable for use with git rebase --autosquash.